PyXMake Developer Guide: PyXMake.VTL.__install__ Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions
PyXMake.VTL.__install__ Namespace Reference

Install minimum working example scripts from PyXMake. More...

## Functions
| main ()

## Detailed Description

Install minimum working example scripts from PyXMake.

    Set up environment for installation procedure of all minimum working example scripts
    for PyXMake

    @note: PyXMake environment file.
    Created on 26.03.2021

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Author
  Marc Garbade

Date
  26.03.2021

Notes/Changes
  - Added documentation // mg 26.03.2021

## Function Documentation

## ◆ main()

PyXMake.VTL.__install__.main | ( |  | ) |

    Main function to execute the script.

Definition at line 36 of file __install__.py.